
For bug reporting, please fill the form here below and set the label to "bug" in
the right hand side. Otherwise, just remove this content and fill your issue as
normal. 

## Version of bioconvert


## Command or code used

For example:
```
bioconvert test.bam test.sam
```

or in Python:

```
from bioconvert.sam2bam import BAM2SAM
...
```

## Expected behaviour

10 lines

## Your results

11 lines

## What you think might have happened

version issue when using the tool XXX
